@@ -581,7 +581,7 @@ static void
 activate (GtkApplication* app,
           gpointer        user_data)
 {
-  GtkWidget *window;
+  GtkWidget *headerbar;
   GtkWidget *label;
   GdkGeometry size_hints = {
     800, 600, 0, 0, 800, 600, 0, 0, 0.0, 0.0, GDK_GRAVITY_NORTH_WEST  
@@ -594,8 +594,15 @@ activate (GtkApplication* app,
 
   GtkBuilder *builder;
 
+  headerbar = gtk_header_bar_new ();
+  gtk_header_bar_set_show_close_button (GTK_HEADER_BAR (headerbar), TRUE);
+  gtk_header_bar_set_title (GTK_HEADER_BAR (headerbar), _("Nibbles"));
+  gtk_widget_show (headerbar);
+
   window = gtk_application_window_new (app);
 
+  gtk_window_set_titlebar (GTK_WINDOW (window), headerbar);
+
   gtk_window_set_geometry_hints (GTK_WINDOW (window),
                     window,
                     &size_hints,
